RefPackError

Enum RefPackError 

pub enum RefPackError {
    EmptyInput,
    BadFlags(u8),
    BadMagic(u8),
    ControlError {
        error: DecodeError,
        position: usize,
    },
    Io(Error),
}
Possible errors returned by compression and decompression functions

Variants



EmptyInput

Error for when no input is provided to a compressor function



BadFlags(u8)

Error that occurs when a flag was set in the header flags that is not supported

Fields
  • u8: What was read instead of the expected flags


BadMagic(u8)

Error indicating that the header failed to read the magic where it expected it. Location depends on the exact implementation.

Fields
  • u8: What was read instead of the magic value


ControlError

Indicates that an invalid operation occurred while attempting to decode a control. This normally indicates invalid or corrupted data.

See DecodeError for further details on types of errors that can occur.

Fields

position: usize


Io(Error)

Generic IO Error wrapper for when a generic IO error of some sort occurs in relation to the readers and writers.