Module refpack::header

source ·
Module for things relating to the header of the data which include decompressed length, sometimes flags or a magic number, and sometimes compressed length.

Modules

possible modes to use for header encoding and decoding

Structs

represents a decoded header

Constants

Magic number in the header. This immediately follows a flag field in most cases